@@ -1,3 +1,5 @@
+# OOP framework for HACSim
+
 ## Master class, both functions return an object of this type
 HACClass <- function(input.seqs = NULL,
                      subset.seqs = NULL,
@@ -10,6 +12,7 @@ HACClass <- function(input.seqs = NULL,
                      p = NA,
                      perms = NA,
                      conf.level = NA,
+                     ci.type = NULL,
                      num.iters = NA,
                      progress = NA,
                      filename = NULL) {
@@ -25,6 +28,7 @@ HACClass <- function(input.seqs = NULL,
     p = p,
     perms = perms,
     conf.level = conf.level,
+    ci.type = ci.type,
     num.iters = num.iters,
     progress = progress,
     filename = filename
@@ -39,6 +43,7 @@ HACClass <- function(input.seqs = NULL,
 HACReal <- function(perms = 10000,
                     p = 0.95,
                     conf.level = 0.95,
+                    ci.type = "quantile",
                     subsample = FALSE,
                     prop = NULL,
                     progress = TRUE,
@@ -64,6 +69,7 @@ HACReal <- function(perms = 10000,
     perms = perms,
     p = p,
     conf.level = conf.level,
+    ci.type = ci.type,
     num.iters = num.iters,
     progress = progress,
     filename = filename
@@ -79,6 +85,7 @@ HACHypothetical <- function(N,
                             perms = 10000,
                             p = 0.95,
                             conf.level = 0.95,
+                            ci.type = "quantile",
                             subsample = FALSE,
                             prop = NULL,
                             progress = TRUE,
@@ -119,6 +126,7 @@ HACHypothetical <- function(N,
     perms = perms,
     p = p,
     conf.level = conf.level,
+    ci.type = ci.type,
     num.iters = num.iters,
     progress = progress,
     filename = filename
