@@ -1,12 +1,16 @@
 
 // [[Rcpp::depends(RcppArmadillo)]]
-// [[Rcpp::depends(RcppProgress)]]
+# // [[Rcpp::depends(RcppProgress)]]
 #define ARMA_DONT_PRINT_OPENMP_WARNING
 #include <RcppArmadillo.h>
 #include <RcppArmadilloExtensions/sample.h>
 #include <set>
 using namespace Rcpp;
 
+// Code used to cumulatively accumulate species' haplotypes
+// Randomly samples individuals (columns) from a given permutation (row) and enumerates
+// the total number of haplotypes found 
+
 int sample_one(int n) {
   return n * unif_rand();
 } 
@@ -39,8 +43,8 @@ arma::Cube<int> accumulate(const arma::Cube<int>& pop,
     int i, j, k;
     
     for (i = 0; i < K; i++) {
-        for (k = 0; k < num_specs; k++) {
-            for (j = 0; j < perms; j++) {
+        for (k = 0; k < num_specs; k++) { 
+            for (j = 0; j < perms; j++) { 
                 pop_ptr = &(pop(sample_one(perms), 0, sample_one(K)));
                 res(j, k, i) = sample_n_distinct(specs_C, k + 1, pop_ptr);
             }
